# Conscript Release Notes

## 0.1.3

+ [305cf38](https://github.com/jsirois/conscript/commit/305cf38) Fixup changelog.

## 0.1.2

+ [2b9d5c7](https://github.com/jsirois/conscript/commit/2b9d5c7) Expand README.
+ [32678ee](https://github.com/jsirois/conscript/commit/32678ee) Unify main completion modes.

## 0.1.1

+ [0f7a388](https://github.com/jsirois/conscript/commit/0f7a388) Fixup release metadata.

## 0.1.0

Initial public release.
